@@ -245,7 +245,7 @@ MGHM <- function(
     #++++ Fit each model in G ++++#
 
     if (progress) {
-      cat('G = ', G, sep = '')
+      cat('Fitting G = ', G, sep = '')
     }
 
     if ( any(is.na(X)) ) {
@@ -425,9 +425,9 @@ MGHM <- function(
 
     if (progress) {
       if (is.null(mod)) {
-        cat('\nFitting G = ', G, ' was failed\n', sep = '')
+        cat(' was failed\n', sep = '')
       } else {
-        cat('Fitting G = ', G, ' was successful\n', sep = '')
+        cat(' was successful with ', mod$iter_stop, '/', max_iter, ' iterations\n', sep = '')
       }
     }
 
@@ -435,6 +435,10 @@ MGHM <- function(
 
   }    # end for (G in G_vec)
 
+  if (progress) {
+    cat('\n')
+  }
+
   #--------------------------------------------#
   #    Summarize Results and Prepare Output    #
   #--------------------------------------------#
@@ -587,11 +591,6 @@ MGHM_incomplete_data <- function(
   #    The EM Algorithm    #
   #------------------------#
 
-  if (progress) {
-    cat('\nModel Fitting:\n')
-    pb <- txtProgressBar(min = 0, max = max_iter, style = 3, width = 75, char = "=")
-  }
-
   while (iter < max_iter & getall(loglik) > epsilon) {
 
     #++++ E-step ++++#
@@ -852,17 +851,6 @@ MGHM_incomplete_data <- function(
 
     iter <- iter + 1
 
-    if (progress) {
-      setTxtProgressBar(pb, iter)
-    }
-
-  }
-
-  if (progress) {
-    close(pb)
-    if (iter < max_iter) {
-      cat('\nConvergence was reached before', max_iter, 'iterations\n')
-    }
   }
 
   #---------------------------#
@@ -1093,11 +1081,6 @@ MGHM_complete_data <- function(
   #    The EM Algorithm    #
   #------------------------#
 
-  if (progress) {
-    cat('\nModel Fitting:\n')
-    pb <- txtProgressBar(min = 0, max = max_iter, style = 3, width = 75, char = "=")
-  }
-
   while (iter < max_iter & getall(loglik) > epsilon) {
 
     #++++ E-step ++++#
@@ -1238,17 +1221,6 @@ MGHM_complete_data <- function(
 
     iter <- iter + 1
 
-    if (progress) {
-      setTxtProgressBar(pb, iter)
-    }
-
-  }
-
-  if (progress) {
-    close(pb)
-    if (iter < max_iter) {
-      cat('\nConvergence was reached before', max_iter, 'iterations\n')
-    }
   }
 
   #---------------------------#
