@@ -109,11 +109,6 @@ MStM_incomplete_data <- function(
   #    The EM Algorithm    #
   #------------------------#
 
-  if (progress) {
-    cat('\nModel Fitting:\n')
-    pb <- txtProgressBar(min = 0, max = max_iter, style = 3, width = 75, char = "=")
-  }
-
   while (iter < max_iter & getall(loglik) > epsilon) {
 
     #++++ E-step ++++#
@@ -340,17 +335,6 @@ MStM_incomplete_data <- function(
 
     iter <- iter + 1
 
-    if (progress) {
-      setTxtProgressBar(pb, iter)
-    }
-
-  }
-
-  if (progress) {
-    close(pb)
-    if (iter < max_iter) {
-      cat('\nConvergence was reached before', max_iter, 'iterations\n')
-    }
   }
 
   #---------------------------#
@@ -562,11 +546,6 @@ MStM_complete_data <- function(
   #    The EM Algorithm    #
   #------------------------#
 
-  if (progress) {
-    cat('\nModel Fitting:\n')
-    pb <- txtProgressBar(min = 0, max = max_iter, style = 3, width = 75, char = "=")
-  }
-
   while (iter < max_iter & getall(loglik) > epsilon) {
 
     #++++ E-step ++++#
@@ -675,17 +654,6 @@ MStM_complete_data <- function(
 
     iter <- iter + 1
 
-    if (progress) {
-      setTxtProgressBar(pb, iter)
-    }
-
-  }
-
-  if (progress) {
-    close(pb)
-    if (iter < max_iter) {
-      cat('\nConvergence was reached before', max_iter, 'iterations\n')
-    }
   }
 
   #---------------------------#
